@@ -67,6 +67,11 @@ pub fn render(frame: &mut Frame, app: &mut App) {
     if app.show_theme_picker {
         render_theme_picker(frame, app, area);
     }
+
+    // Render link picker if in link follow mode with links
+    if matches!(app.mode, crate::tui::app::AppMode::LinkFollow) && !app.links_in_view.is_empty() {
+        render_link_picker(frame, app, area);
+    }
 }
 
 fn render_title_bar(frame: &mut Frame, app: &App, area: Rect) {
@@ -101,12 +106,11 @@ fn render_outline(frame: &mut Frame, app: &mut App, area: Rect) {
             };
 
             // Show bookmark indicator if this item's text matches the bookmark
-            let bookmark_indicator =
-                if app.bookmark_position.as_deref() == Some(&item.text) {
-                    "⚑ "
-                } else {
-                    ""
-                };
+            let bookmark_indicator = if app.bookmark_position.as_deref() == Some(&item.text) {
+                "⚑ "
+            } else {
+                ""
+            };
 
             // Color headings by level using theme
             let color = theme.heading_color(item.level);
@@ -153,18 +157,33 @@ fn render_outline(frame: &mut Frame, app: &mut App, area: Rect) {
 }
 
 fn render_content(frame: &mut Frame, app: &App, area: Rect) {
+    use crate::tui::app::AppMode;
+
     let theme = &app.theme;
     let block_style = theme.border_style(app.focus == Focus::Content);
 
     // Get content for selected section and determine title
     let (content_text, title) = if let Some(heading_text) = app.selected_heading_text() {
-        let content = app.document
+        let content = app
+            .document
             .extract_section(heading_text)
             .unwrap_or_else(|| app.document.content.clone());
-        let title = format!(" {} ", heading_text);
+
+        // Add link count to title if in link follow mode
+        let title = if app.mode == AppMode::LinkFollow && !app.links_in_view.is_empty() {
+            format!(" {} [Links: {}] ", heading_text, app.links_in_view.len())
+        } else {
+            format!(" {} ", heading_text)
+        };
+
         (content, title)
     } else {
-        (app.document.content.clone(), " Content ".to_string())
+        let title = if app.mode == AppMode::LinkFollow && !app.links_in_view.is_empty() {
+            format!(" Content [Links: {}] ", app.links_in_view.len())
+        } else {
+            " Content ".to_string()
+        };
+        (app.document.content.clone(), title)
     };
 
     // Enhanced markdown rendering with syntax highlighting
@@ -200,51 +219,133 @@ fn render_content(frame: &mut Frame, app: &App, area: Rect) {
 }
 
 fn render_status_bar(frame: &mut Frame, app: &App, area: Rect) {
-    let focus_indicator = match app.focus {
-        Focus::Outline => "Outline",
-        Focus::Content => "Content",
-    };
+    use crate::tui::app::AppMode;
 
-    let selected_idx = app.outline_state.selected().unwrap_or(0);
-    let total = app.outline_items.len();
-    let percentage = if total > 0 {
-        (selected_idx + 1) * 100 / total
+    // If there's a status message, display it prominently
+    if let Some(ref msg) = app.status_message {
+        let status = Paragraph::new(msg.clone()).style(
+            Style::default()
+                .bg(Color::Rgb(0, 80, 120))
+                .fg(Color::White)
+                .add_modifier(Modifier::BOLD),
+        );
+        frame.render_widget(status, area);
+        return;
+    }
+
+    let status_text = if app.mode == AppMode::LinkFollow {
+        // Link follow mode status
+        let link_count = app.links_in_view.len();
+        let selected = app.selected_link_idx.map(|i| i + 1).unwrap_or(0);
+
+        let link_info = if link_count > 0 {
+            // Show current link details
+            let current_link = app
+                .selected_link_idx
+                .and_then(|idx| app.links_in_view.get(idx));
+
+            if let Some(link) = current_link {
+                use crate::parser::LinkTarget;
+                let target_str = match &link.target {
+                    LinkTarget::Anchor(a) => format!("#{}", a),
+                    LinkTarget::RelativeFile { path, anchor } => {
+                        if let Some(a) = anchor {
+                            format!("{}#{}", path.display(), a)
+                        } else {
+                            path.display().to_string()
+                        }
+                    }
+                    LinkTarget::WikiLink { target, .. } => format!("[[{}]]", target),
+                    LinkTarget::External(url) => {
+                        // Truncate long URLs
+                        if url.len() > 40 {
+                            format!("{}...", &url[..37])
+                        } else {
+                            url.clone()
+                        }
+                    }
+                };
+
+                format!(
+                    "Link {}/{}: \"{}\" → {} • Tab:Next • Enter:Follow • Esc:Exit",
+                    selected, link_count, link.text, target_str
+                )
+            } else {
+                format!(
+                    "Link {}/{} • Tab:Next • 1-9:Jump • Enter:Follow • Esc:Exit",
+                    selected, link_count
+                )
+            }
+        } else {
+            "No links in current section • Press Esc to exit".to_string()
+        };
+
+        format!(" [LINK FOLLOW MODE] {} ", link_info)
     } else {
-        0
-    };
+        // Normal mode status
+        let focus_indicator = match app.focus {
+            Focus::Outline => "Outline",
+            Focus::Content => "Content",
+        };
 
-    let outline_status = if app.show_outline {
-        format!("Outline:{}%", app.outline_width)
-    } else {
-        "Outline:Hidden".to_string()
-    };
+        let selected_idx = app.outline_state.selected().unwrap_or(0);
+        let total = app.outline_items.len();
+        let percentage = if total > 0 {
+            (selected_idx + 1) * 100 / total
+        } else {
+            0
+        };
 
-    let bookmark_indicator = if app.bookmark_position.is_some() {
-        " ⚑"
-    } else {
-        ""
-    };
+        let outline_status = if app.show_outline {
+            format!("Outline:{}%", app.outline_width)
+        } else {
+            "Outline:Hidden".to_string()
+        };
 
-    let status_text = format!(
-        " [{}] {}/{} ({}%){} • {} • w:View • []:Size • m:Mark • Copy: y:Text Y:Link • t:Theme • ?:Help ",
-        focus_indicator,
-        selected_idx + 1,
-        total,
-        percentage,
-        bookmark_indicator,
-        outline_status
-    );
+        let bookmark_indicator = if app.bookmark_position.is_some() {
+            " ⚑"
+        } else {
+            ""
+        };
+
+        let history_indicator = if !app.file_history.is_empty() {
+            format!(" ← {} ", app.file_history.len())
+        } else {
+            "".to_string()
+        };
+
+        format!(
+            " [{}] {}/{} ({}%){}{} • {} • f:Links • b:Back • w:View • []:Size • m:Mark • y/Y:Copy • t:Theme • ?:Help ",
+            focus_indicator,
+            selected_idx + 1,
+            total,
+            percentage,
+            bookmark_indicator,
+            history_indicator,
+            outline_status
+        )
+    };
 
     let theme_name = format!(" Theme:{} ", app.theme.name);
     let status_text = format!("{}{}", status_text, theme_name);
 
-    let status = Paragraph::new(status_text).style(app.theme.status_bar_style());
+    let status_style = if app.mode == AppMode::LinkFollow {
+        Style::default()
+            .bg(Color::Rgb(0, 100, 0))
+            .fg(Color::White)
+            .add_modifier(Modifier::BOLD)
+    } else {
+        app.theme.status_bar_style()
+    };
+
+    let status = Paragraph::new(status_text).style(status_style);
 
     frame.render_widget(status, area);
 }
 
 fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
     let popup_area = centered_area(area, 70, 80);
+    let theme = &app.theme;
 
     // Clear the area
     frame.render_widget(Clear, popup_area);
@@ -253,13 +354,13 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
         Line::from(vec![Span::styled(
             "treemd - Keyboard Shortcuts",
             Style::default()
-                .fg(Color::Cyan)
+                .fg(theme.modal_title())
                 .add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![Span::styled(
             "Use j/k or ↓/↑ to scroll | Press Esc or ? to close",
             Style::default()
-                .fg(Color::Gray)
+                .fg(theme.modal_description())
                 .add_modifier(Modifier::ITALIC),
         )]),
         Line::from(""),
@@ -268,27 +369,31 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
             Style::default().add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![
-            Span::styled("  j/↓      ", Style::default().fg(Color::Yellow)),
+            Span::styled("  j/↓      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Move down"),
         ]),
         Line::from(vec![
-            Span::styled("  k/↑      ", Style::default().fg(Color::Yellow)),
+            Span::styled("  k/↑      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Move up"),
         ]),
         Line::from(vec![
-            Span::styled("  g        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  g        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Jump to top"),
         ]),
         Line::from(vec![
-            Span::styled("  G        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  G        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Jump to bottom"),
         ]),
         Line::from(vec![
-            Span::styled("  d        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  p        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Jump to parent heading"),
+        ]),
+        Line::from(vec![
+            Span::styled("  d        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Page down (content)"),
         ]),
         Line::from(vec![
-            Span::styled("  u        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  u        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Page up (content)"),
         ]),
         Line::from(""),
@@ -297,15 +402,15 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
             Style::default().add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![
-            Span::styled("  Enter/Space ", Style::default().fg(Color::Yellow)),
+            Span::styled("  Enter/Space ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Toggle expand/collapse"),
         ]),
         Line::from(vec![
-            Span::styled("  l/→      ", Style::default().fg(Color::Yellow)),
+            Span::styled("  l/→      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Expand heading"),
         ]),
         Line::from(vec![
-            Span::styled("  h/←      ", Style::default().fg(Color::Yellow)),
+            Span::styled("  h/←      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Collapse (or parent if no children)"),
         ]),
         Line::from(""),
@@ -314,19 +419,19 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
             Style::default().add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![
-            Span::styled("  Tab      ", Style::default().fg(Color::Yellow)),
+            Span::styled("  Tab      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Switch between Outline and Content"),
         ]),
         Line::from(vec![
-            Span::styled("  /        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  /        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Search/filter headings"),
         ]),
         Line::from(vec![
-            Span::styled("  ?        ", Style::default().fg(Color::Yellow)),
+            Span::styled("  ?        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Toggle this help"),
         ]),
         Line::from(vec![
-            Span::styled("  q/Esc    ", Style::default().fg(Color::Yellow)),
+            Span::styled("  q/Esc    ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Quit"),
         ]),
         Line::from(""),
@@ -335,47 +440,97 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
             Style::default().add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![
-            Span::styled("  w        ", Style::default().fg(Color::Cyan)),
+            Span::styled("  w        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Toggle outline visibility (full-width content)"),
         ]),
         Line::from(vec![
-            Span::styled("  [ ]      ", Style::default().fg(Color::Cyan)),
+            Span::styled("  [ ]      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Decrease/increase outline width (20%, 30%, 40%)"),
         ]),
         Line::from(vec![
-            Span::styled("  1-9      ", Style::default().fg(Color::Cyan)),
+            Span::styled("  1-9      ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Jump to heading 1-9"),
         ]),
         Line::from(vec![
-            Span::styled("  m        ", Style::default().fg(Color::Cyan)),
+            Span::styled("  m        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Set bookmark (shows ⚑ indicator)"),
         ]),
         Line::from(vec![
-            Span::styled("  '        ", Style::default().fg(Color::Cyan)),
+            Span::styled("  '        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Jump to bookmarked position"),
         ]),
         Line::from(""),
+        Line::from(vec![Span::styled(
+            "Link Following",
+            Style::default().add_modifier(Modifier::BOLD),
+        )]),
+        Line::from(vec![
+            Span::styled("  f        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Enter link follow mode"),
+        ]),
+        Line::from(vec![
+            Span::styled("  Tab      ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Cycle through links (in link mode)"),
+        ]),
+        Line::from(vec![
+            Span::styled("  1-9      ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Jump to link by number (in link mode)"),
+        ]),
+        Line::from(vec![
+            Span::styled("  Enter    ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Follow selected link (in link mode)"),
+        ]),
+        Line::from(vec![
+            Span::styled("  p        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Jump to parent's links (stay in link mode)"),
+        ]),
+        Line::from(vec![
+            Span::styled("  b/Bksp   ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Go back to previous file"),
+        ]),
+        Line::from(vec![
+            Span::styled("  F        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Go forward in navigation history"),
+        ]),
+        Line::from(""),
         Line::from(vec![Span::styled(
             "Themes & Clipboard",
             Style::default().add_modifier(Modifier::BOLD),
         )]),
         Line::from(vec![
-            Span::styled("  t        ", Style::default().fg(Color::Magenta)),
+            Span::styled("  t        ", Style::default().fg(theme.modal_key_fg())),
             Span::raw("Cycle color theme"),
         ]),
         Line::from(vec![
-            Span::styled("  y        ", Style::default().fg(Color::Magenta)),
-            Span::raw("Copy current section content"),
+            Span::styled("  y        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Copy current section content (works in all modes)"),
         ]),
         Line::from(vec![
-            Span::styled("  Y        ", Style::default().fg(Color::Magenta)),
-            Span::raw("Copy anchor link (#heading-name)"),
+            Span::styled("  Y        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Copy anchor link (works in all modes)"),
+        ]),
+        Line::from(vec![
+            Span::styled("  e        ", Style::default().fg(theme.modal_key_fg())),
+            Span::raw("Edit file in default editor ($VISUAL or $EDITOR)"),
+        ]),
+        Line::from(""),
+        Line::from(vec![
+            Span::styled(
+                "Note: ",
+                Style::default()
+                    .fg(theme.modal_selected_marker())
+                    .add_modifier(Modifier::BOLD),
+            ),
+            Span::styled(
+                "On Linux, install a clipboard manager (clipit, parcellite, xclip) for best results",
+                Style::default().fg(theme.modal_description()),
+            ),
         ]),
         Line::from(""),
         Line::from(vec![Span::styled(
             "Use j/k or ↓/↑ to scroll | Press Esc or ? to close",
             Style::default()
-                .fg(Color::Gray)
+                .fg(theme.modal_description())
                 .add_modifier(Modifier::ITALIC),
         )]),
     ];
@@ -386,9 +541,9 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
         .block(
             Block::default()
                 .borders(Borders::ALL)
-                .border_style(Style::default().fg(Color::Cyan))
+                .border_style(Style::default().fg(theme.modal_border()))
                 .title(" Help ")
-                .style(Style::default().bg(Color::Rgb(20, 20, 40))),
+                .style(Style::default().bg(theme.modal_bg())),
         )
         .wrap(Wrap { trim: false })
         .scroll((app.help_scroll, 0));
@@ -399,7 +554,7 @@ fn render_help_popup(frame: &mut Frame, app: &App, area: Rect) {
     let scrollbar = Scrollbar::new(ScrollbarOrientation::VerticalRight)
         .begin_symbol(Some("↑"))
         .end_symbol(Some("↓"))
-        .style(Style::default().fg(Color::Cyan));
+        .style(Style::default().fg(theme.modal_border()));
 
     let mut scrollbar_state = ScrollbarState::new(help_text_len).position(app.help_scroll as usize);
 
@@ -421,6 +576,127 @@ fn centered_area(area: Rect, percent_x: u16, percent_y: u16) -> Rect {
     area
 }
 
+fn render_link_picker(frame: &mut Frame, app: &App, area: Rect) {
+    use crate::parser::LinkTarget;
+
+    let theme = &app.theme;
+
+    // Create centered popup area (smaller than full screen)
+    let popup_area = centered_area(area, 80, 60);
+
+    // Clear background
+    frame.render_widget(Clear, popup_area);
+
+    // Create lines for each link
+    let mut lines = vec![
+        Line::from(vec![Span::styled(
+            format!(
+                "Links in this section ({} found) - Tab/j/k to navigate, Enter to follow, Esc to cancel",
+                app.links_in_view.len()
+            ),
+            Style::default()
+                .fg(theme.modal_title())
+                .add_modifier(Modifier::BOLD),
+        )]),
+        Line::from(""),
+    ];
+
+    for (idx, link) in app.links_in_view.iter().enumerate() {
+        let is_selected = app.selected_link_idx == Some(idx);
+
+        // Format link number and text
+        let number = format!("[{}] ", idx + 1);
+        let link_text = &link.text;
+
+        // Format target
+        let target_str = match &link.target {
+            LinkTarget::Anchor(a) => format!("#{}", a),
+            LinkTarget::RelativeFile { path, anchor } => {
+                if let Some(a) = anchor {
+                    format!("{}#{}", path.display(), a)
+                } else {
+                    path.display().to_string()
+                }
+            }
+            LinkTarget::WikiLink { target, .. } => format!("[[{}]]", target),
+            LinkTarget::External(url) => {
+                if url.len() > 50 {
+                    format!("{}...", &url[..47])
+                } else {
+                    url.clone()
+                }
+            }
+        };
+
+        // Different styles for selected vs unselected
+        if is_selected {
+            lines.push(Line::from(vec![
+                Span::styled(
+                    "▶ ",
+                    Style::default()
+                        .fg(theme.modal_selected_marker())
+                        .add_modifier(Modifier::BOLD),
+                ),
+                Span::styled(
+                    number,
+                    Style::default()
+                        .fg(theme.modal_key_fg())
+                        .add_modifier(Modifier::BOLD),
+                ),
+                Span::styled(
+                    link_text,
+                    Style::default()
+                        .fg(theme.modal_selected_fg())
+                        .add_modifier(Modifier::BOLD | Modifier::UNDERLINED),
+                ),
+            ]));
+            // Show target on next line when selected
+            lines.push(Line::from(vec![Span::styled(
+                format!("  → {}", target_str),
+                Style::default()
+                    .fg(theme.modal_description())
+                    .add_modifier(Modifier::ITALIC),
+            )]));
+        } else {
+            lines.push(Line::from(vec![
+                Span::styled("  ", Style::default()),
+                Span::styled(number, Style::default().fg(theme.modal_description())),
+                Span::styled(link_text, Style::default().fg(theme.modal_text())),
+                Span::styled(
+                    format!(" → {}", target_str),
+                    Style::default().fg(theme.modal_description()),
+                ),
+            ]));
+        }
+
+        // Add blank line between links
+        if idx < app.links_in_view.len() - 1 {
+            lines.push(Line::from(""));
+        }
+    }
+
+    // Add footer
+    lines.push(Line::from(""));
+    lines.push(Line::from(vec![Span::styled(
+        "Tab/j/k: Navigate • 1-9: Jump • p: Parent • Enter: Follow • Esc: Cancel",
+        Style::default()
+            .fg(theme.modal_description())
+            .add_modifier(Modifier::ITALIC),
+    )]));
+
+    let paragraph = Paragraph::new(lines)
+        .block(
+            Block::default()
+                .borders(Borders::ALL)
+                .border_style(Style::default().fg(theme.modal_border()))
+                .title(" Link Navigator ")
+                .style(Style::default().bg(theme.modal_bg())),
+        )
+        .wrap(Wrap { trim: false });
+
+    frame.render_widget(paragraph, popup_area);
+}
+
 use crate::tui::syntax::SyntaxHighlighter;
 
 fn render_markdown_enhanced(
@@ -437,7 +713,7 @@ fn render_markdown_enhanced(
         let trimmed = line.trim_start();
 
         // Handle code blocks
-        if trimmed.starts_with("```") {
+        if let Some(after_fence) = trimmed.strip_prefix("```") {
             if in_code_block {
                 // End of code block - highlight accumulated code
                 if !code_buffer.is_empty() {
@@ -453,7 +729,7 @@ fn render_markdown_enhanced(
             } else {
                 // Start of code block
                 in_code_block = true;
-                code_lang = SyntaxHighlighter::detect_language(&trimmed[3..]);
+                code_lang = SyntaxHighlighter::detect_language(after_fence);
                 lines.push(Line::from(vec![Span::styled(
                     line.to_string(),
                     theme.code_fence_style(),
@@ -489,14 +765,13 @@ fn render_markdown_enhanced(
             lines.push(Line::from(spans));
         }
         // Numbered lists
-        else if trimmed.chars().next().is_some_and(|c| c.is_numeric()) && trimmed.contains(". ")
-        {
+        else if trimmed.chars().next().is_some_and(|c| c.is_numeric()) && trimmed.contains(". ") {
             let formatted = format_inline_markdown(line, theme);
             lines.push(Line::from(formatted));
         }
         // Blockquotes
-        else if trimmed.starts_with('>') {
-            let text = trimmed[1..].trim();
+        else if let Some(quote_text) = trimmed.strip_prefix('>') {
+            let text = quote_text.trim();
             let formatted = format_inline_markdown(text, theme);
             let mut spans = vec![Span::styled(
                 "│ ",
@@ -623,6 +898,8 @@ fn render_search_overlay(frame: &mut Frame, app: &App, area: Rect) {
 fn render_theme_picker(frame: &mut Frame, app: &App, area: Rect) {
     use crate::tui::theme::ThemeName;
 
+    let theme = &app.theme;
+
     // All available themes
     let themes = [
         (
@@ -670,7 +947,7 @@ fn render_theme_picker(frame: &mut Frame, app: &App, area: Rect) {
         Line::from(vec![Span::styled(
             "Select Theme (j/k to navigate, Enter to apply, Esc to cancel)",
             Style::default()
-                .fg(Color::Gray)
+                .fg(theme.modal_description())
                 .add_modifier(Modifier::ITALIC),
         )]),
         Line::from(""),
@@ -684,11 +961,11 @@ fn render_theme_picker(frame: &mut Frame, app: &App, area: Rect) {
             (
                 "▶ ",
                 Style::default()
-                    .fg(Color::Cyan)
+                    .fg(theme.modal_selected_fg())
                     .add_modifier(Modifier::BOLD),
             )
         } else {
-            ("  ", Style::default().fg(Color::White))
+            ("  ", Style::default().fg(theme.modal_text()))
         };
 
         let current_marker = if is_current { " ✓" } else { "" };
@@ -701,7 +978,7 @@ fn render_theme_picker(frame: &mut Frame, app: &App, area: Rect) {
             lines.push(Line::from(vec![Span::styled(
                 format!("  {}", description),
                 Style::default()
-                    .fg(Color::Gray)
+                    .fg(theme.modal_description())
                     .add_modifier(Modifier::ITALIC),
             )]));
         }
@@ -713,9 +990,9 @@ fn render_theme_picker(frame: &mut Frame, app: &App, area: Rect) {
         .block(
             Block::default()
                 .borders(Borders::ALL)
-                .border_style(Style::default().fg(Color::Cyan))
+                .border_style(Style::default().fg(theme.modal_border()))
                 .title(" Theme Selector ")
-                .style(Style::default().bg(Color::Rgb(20, 20, 30))),
+                .style(Style::default().bg(theme.modal_bg())),
         )
         .wrap(Wrap { trim: false });
 
